#
# Script module for module 'Az.Sql' that is executed when 'Az.Sql' is imported in a PowerShell session.
#
# Generated by: Microsoft Corporation
#
# Generated on: 08/30/2023 06:21:38
#

$PSDefaultParameterValues.Clear()
Set-StrictMode -Version Latest

function Test-DotNet
{
    try
    {
        if ((Get-PSDrive 'HKLM' -ErrorAction Ignore) -and (-not (Get-ChildItem 'HKLM:\SOFTWARE\Microsoft\NET Framework Setup\NDP\v4\Full\' -ErrorAction Stop | Get-ItemPropertyValue -ErrorAction Stop -Name Release | Where-Object { $_ -ge 461808 })))
        {
            throw ".NET Framework versions lower than 4.7.2 are not supported in Az. Please upgrade to .NET Framework 4.7.2 or higher."
        }
    }
    catch [System.Management.Automation.DriveNotFoundException]
    {
        Write-Verbose ".NET Framework version check failed."
    }
}

function Preload-Assembly {
    param (
        [string]
        $AssemblyDirectory
    )
    if($PSEdition -eq 'Desktop' -and (Test-Path $AssemblyDirectory -ErrorAction Ignore))
    {
        try
        {
            Get-ChildItem -ErrorAction Stop -Path $AssemblyDirectory -Filter "*.dll" | ForEach-Object {
                try
                {
                    Add-Type -Path $_.FullName -ErrorAction Ignore | Out-Null
                }
                catch {
                    Write-Verbose $_
                }
            }
        }
        catch {}
    }
}

if ($true -and ($PSEdition -eq 'Desktop'))
{
    if ($PSVersionTable.PSVersion -lt [Version]'5.1')
    {
        throw "PowerShell versions lower than 5.1 are not supported in Az. Please upgrade to PowerShell 5.1 or higher."
    }

    Test-DotNet
}

if ($true -and ($PSEdition -eq 'Core'))
{
    if ($PSVersionTable.PSVersion -lt [Version]'6.2.4')
    {
        throw "Current Az version doesn't support PowerShell Core versions lower than 6.2.4. Please upgrade to PowerShell Core 6.2.4 or higher."
    }
}

if (Test-Path -Path "$PSScriptRoot\StartupScripts" -ErrorAction Ignore)
{
    Get-ChildItem "$PSScriptRoot\StartupScripts" -ErrorAction Stop | ForEach-Object {
        . $_.FullName
    }
}

# [windows powershell] preload assemblies


# [windows powershell] preload module alc assemblies
$preloadPath = (Join-Path $PSScriptRoot -ChildPath "ModuleAlcAssemblies")
Preload-Assembly -AssemblyDirectory $preloadPath

if (Get-Module AzureRM.profile -ErrorAction Ignore)
{
    Write-Warning ("AzureRM.Profile already loaded. Az and AzureRM modules cannot be imported in the same session or used in the same script or runbook. If you are running PowerShell in an environment you control you can use the 'Uninstall-AzureRm' cmdlet to remove all AzureRm modules from your machine. " +
        "If you are running in Azure Automation, take care that none of your runbooks import both Az and AzureRM modules. More information can be found here: https://aka.ms/azps-migration-guide.")
    throw ("AzureRM.Profile already loaded. Az and AzureRM modules cannot be imported in the same session or used in the same script or runbook. If you are running PowerShell in an environment you control you can use the 'Uninstall-AzureRm' cmdlet to remove all AzureRm modules from your machine. " +
        "If you are running in Azure Automation, take care that none of your runbooks import both Az and AzureRM modules. More information can be found here: https://aka.ms/azps-migration-guide.")
}

$module = Get-Module Az.Accounts 
        if ($module -ne $null -and $module.Version -lt [System.Version]"2.13.0") 
{ 
    Write-Error "This module requires Az.Accounts version 2.13.0. An earlier version of Az.Accounts is imported in the current PowerShell session. Please open a new session before importing this module. This error could indicate that multiple incompatible versions of the Azure PowerShell cmdlets are installed on your system. Please see https://aka.ms/azps-version-error for troubleshooting information." -ErrorAction Stop 
} 
elseif ($module -eq $null) 
{ 
    Import-Module Az.Accounts -MinimumVersion 2.13.0 -Scope Global 
}
Import-Module (Join-Path -Path $PSScriptRoot -ChildPath Microsoft.Azure.PowerShell.Cmdlets.Sql.dll)


if (Test-Path -Path "$PSScriptRoot\PostImportScripts" -ErrorAction Ignore)
{
    Get-ChildItem "$PSScriptRoot\PostImportScripts" -ErrorAction Stop | ForEach-Object {
        . $_.FullName
    }
}

$FilteredCommands = @('Clear-AzSqlDatabaseVulnerabilityAssessmentSetting:ResourceGroupName','Get-AzSqlDatabaseVulnerabilityAssessmentSetting:ResourceGroupName','Update-AzSqlDatabaseVulnerabilityAssessmentSetting:ResourceGroupName','Clear-AzSqlInstanceDatabaseVulnerabilityAssessmentSetting:ResourceGroupName','Get-AzSqlInstanceDatabaseVulnerabilityAssessmentSetting:ResourceGroupName','Update-AzSqlInstanceDatabaseVulnerabilityAssessmentSetting:ResourceGroupName','Convert-AzSqlDatabaseVulnerabilityAssessmentScan:ResourceGroupName','Get-AzSqlDatabaseVulnerabilityAssessmentScanRecord:ResourceGroupName','Start-AzSqlDatabaseVulnerabilityAssessmentScan:ResourceGroupName','Convert-AzSqlInstanceDatabaseVulnerabilityAssessmentScan:ResourceGroupName','Get-AzSqlInstanceDatabaseVulnerabilityAssessmentScanRecord:ResourceGroupName','Start-AzSqlInstanceDatabaseVulnerabilityAssessmentScan:ResourceGroupName','Clear-AzSqlDatabaseVulnerabilityAssessmentRuleBaseline:ResourceGroupName','Get-AzSqlDatabaseVulnerabilityAssessmentRuleBaseline:ResourceGroupName','Set-AzSqlDatabaseVulnerabilityAssessmentRuleBaseline:ResourceGroupName','Clear-AzSqlInstanceDatabaseVulnerabilityAssessmentRuleBaseline:ResourceGroupName','Get-AzSqlInstanceDatabaseVulnerabilityAssessmentRuleBaseline:ResourceGroupName','Set-AzSqlInstanceDatabaseVulnerabilityAssessmentRuleBaseline:ResourceGroupName','Get-AzSqlServerVirtualNetworkRule:ResourceGroupName','New-AzSqlServerVirtualNetworkRule:ResourceGroupName','Remove-AzSqlServerVirtualNetworkRule:ResourceGroupName','Set-AzSqlServerVirtualNetworkRule:ResourceGroupName','Get-AzSqlDatabaseTransparentDataEncryption:ResourceGroupName','Get-AzSqlServerTransparentDataEncryptionProtector:ResourceGroupName','Invoke-AzSqlServerTransparentDataEncryptionProtectorRevalidation:ResourceGroupName','Set-AzSqlDatabaseTransparentDataEncryption:ResourceGroupName','Set-AzSqlServerTransparentDataEncryptionProtector:ResourceGroupName','Get-AzSqlDatabaseUpgradeHint:ResourceGroupName','Get-AzSqlServerUpgradeHint:ResourceGroupName','New-AzSqlServer:ResourceGroupName','Remove-AzSqlServer:ResourceGroupName','Set-AzSqlServer:ResourceGroupName','New-AzSqlServerTrustGroup:ResourceGroupName','Remove-AzSqlServerTrustGroup:ResourceGroupName','Add-AzSqlServerKeyVaultKey:ResourceGroupName','Get-AzSqlServerKeyVaultKey:ResourceGroupName','Remove-AzSqlServerKeyVaultKey:ResourceGroupName','Get-AzSqlServerDnsAlias:ResourceGroupName','New-AzSqlServerDnsAlias:ResourceGroupName','Set-AzSqlServerDnsAlias:ResourceGroupName','Get-AzSqlServerDisasterRecoveryConfiguration:ResourceGroupName','Get-AzSqlServerDisasterRecoveryConfigurationActivity:ResourceGroupName','New-AzSqlServerDisasterRecoveryConfiguration:ResourceGroupName','Remove-AzSqlServerDisasterRecoveryConfiguration:ResourceGroupName','Set-AzSqlServerDisasterRecoveryConfiguration:ResourceGroupName','Get-AzSqlServerCommunicationLink:ResourceGroupName','New-AzSqlServerCommunicationLink:ResourceGroupName','Remove-AzSqlServerCommunicationLink:ResourceGroupName','Get-AzSqlServerActiveDirectoryAdministrator:ResourceGroupName','Remove-AzSqlServerActiveDirectoryAdministrator:ResourceGroupName','Set-AzSqlServerActiveDirectoryAdministrator:ResourceGroupName','Get-AzSqlDatabaseReplicationLink:ResourceGroupName','New-AzSqlDatabaseCopy:ResourceGroupName','New-AzSqlDatabaseSecondary:ResourceGroupName','Remove-AzSqlDatabaseSecondary:ResourceGroupName','Set-AzSqlDatabaseSecondary:ResourceGroupName','Get-AzSqlElasticPoolRecommendation:ResourceGroupName','Get-AzSqlDatabaseRecommendedAction:ResourceGroupName','Get-AzSqlElasticPoolRecommendedAction:ResourceGroupName','Get-AzSqlServerRecommendedAction:ResourceGroupName','Set-AzSqlDatabaseRecommendedActionState:ResourceGroupName','Set-AzSqlElasticPoolRecommendedActionState:ResourceGroupName','Set-AzSqlServerRecommendedActionState:ResourceGroupName','Get-AzSqlServerOutboundFirewallRule:ResourceGroupName','New-AzSqlServerOutboundFirewallRule:ResourceGroupName','Remove-AzSqlServerOutboundFirewallRule:ResourceGroupName','Get-AzSqlInstanceStartStopSchedule:ResourceGroupName','New-AzSqlInstanceStartStopSchedule:ResourceGroupName','Remove-AzSqlInstanceStartStopSchedule:ResourceGroupName','Invoke-AzSqlInstanceFailover:ResourceGroupName','Start-AzSqlInstance:ResourceGroupName','Stop-AzSqlInstance:ResourceGroupName','Get-AzSqlInstanceDatabaseLogReplay:ResourceGroupName','Get-AzSqlInstanceDatabaseCopyOperation:ResourceGroupName','Get-AzSqlInstanceDatabaseMoveOperation:ResourceGroupName','Get-AzSqlDeletedInstanceDatabaseBackup:ResourceGroupName','Get-AzSqlInstanceDatabaseBackupLongTermRetentionPolicy:ResourceGroupName','Set-AzSqlInstanceDatabaseBackupLongTermRetentionPolicy:ResourceGroupName','Get-AzSqlServerIpv6FirewallRule:ResourceGroupName','New-AzSqlServerIpv6FirewallRule:ResourceGroupName','Remove-AzSqlServerIpv6FirewallRule:ResourceGroupName','Set-AzSqlServerIpv6FirewallRule:ResourceGroupName','New-AzSqlInstancePool:ResourceGroupName','Get-AzSqlDatabaseInstanceFailoverGroup:ResourceGroupName','New-AzSqlDatabaseInstanceFailoverGroup:ResourceGroupName','Get-AzSqlDatabaseIndexRecommendation:ResourceGroupName','Start-AzSqlDatabaseExecuteIndexRecommendation:ResourceGroupName','Stop-AzSqlDatabaseExecuteIndexRecommendation:ResourceGroupName','New-AzSqlDatabaseExport:ResourceGroupName','New-AzSqlDatabaseImport:ResourceGroupName','Get-AzSqlServerFirewallRule:ResourceGroupName','New-AzSqlServerFirewallRule:ResourceGroupName','Remove-AzSqlServerFirewallRule:ResourceGroupName','Set-AzSqlServerFirewallRule:ResourceGroupName','Add-AzSqlDatabaseToFailoverGroup:ResourceGroupName','Get-AzSqlDatabaseFailoverGroup:ResourceGroupName','New-AzSqlDatabaseFailoverGroup:ResourceGroupName','Remove-AzSqlDatabaseFromFailoverGroup:ResourceGroupName','Remove-AzSqlDatabaseFailoverGroup:ResourceGroupName','Set-AzSqlDatabaseFailoverGroup:ResourceGroupName','Switch-AzSqlDatabaseFailoverGroup:ResourceGroupName','Invoke-AzSqlServerExternalGovernanceStatusRefresh:ResourceGroupName','Get-AzSqlElasticPool:ResourceGroupName','Get-AzSqlElasticPoolActivity:ResourceGroupName','Get-AzSqlElasticPoolDatabase:ResourceGroupName','Invoke-AzSqlElasticPoolFailover:ResourceGroupName','New-AzSqlElasticPool:ResourceGroupName','Remove-AzSqlElasticPool:ResourceGroupName','Set-AzSqlElasticPool:ResourceGroupName','Stop-AzSqlElasticPoolActivity:ResourceGroupName','Get-AzSqlDatabase:ResourceGroupName','Get-AzSqlDatabaseActivity:ResourceGroupName','Get-AzSqlDatabaseExpanded:ResourceGroupName','Invoke-AzSqlDatabaseFailover:ResourceGroupName','Invoke-AzSqlDatabaseTransparentDataEncryptionProtectorRevalidation:ResourceGroupName','Invoke-AzSqlDatabaseTransparentDataEncryptionProtectorRevert:ResourceGroupName','New-AzSqlDatabase:ResourceGroupName','Remove-AzSqlDatabase:ResourceGroupName','Set-AzSqlDatabase:ResourceGroupName','Stop-AzSqlDatabaseActivity:ResourceGroupName','Get-AzSqlDatabaseGeoBackup:ResourceGroupName','Get-AzSqlDeletedDatabaseBackup:ResourceGroupName','Get-AzSqlDatabaseBackupLongTermRetentionPolicy:ResourceGroupName','Get-AzSqlDatabaseGeoBackupPolicy:ResourceGroupName','Get-AzSqlDatabaseRestorePoint:ResourceGroupName','New-AzSqlDatabaseRestorePoint:ResourceGroupName','Remove-AzSqlDatabaseRestorePoint:ResourceGroupName','Restore-AzSqlDatabase:ResourceGroupName','Set-AzSqlDatabaseBackupLongTermRetentionPolicy:ResourceGroupName','Set-AzSqlDatabaseGeoBackupPolicy:ResourceGroupName','Resume-AzSqlDatabase:ResourceGroupName','Suspend-AzSqlDatabase:ResourceGroupName','Get-AzSqlSyncAgent:ResourceGroupName','Get-AzSqlSyncAgentLinkedDatabase:ResourceGroupName','Get-AzSqlSyncGroup:ResourceGroupName','Get-AzSqlSyncGroupLog:ResourceGroupName','Get-AzSqlSyncMember:ResourceGroupName','Get-AzSqlSyncSchema:ResourceGroupName','New-AzSqlSyncAgent:ResourceGroupName','New-AzSqlSyncAgentKey:ResourceGroupName','New-AzSqlSyncGroup:ResourceGroupName','New-AzSqlSyncMember:ResourceGroupName','Remove-AzSqlSyncAgent:ResourceGroupName','Remove-AzSqlSyncGroup:ResourceGroupName','Remove-AzSqlSyncMember:ResourceGroupName','Start-AzSqlSyncGroupSync:ResourceGroupName','Stop-AzSqlSyncGroupSync:ResourceGroupName','Update-AzSqlSyncGroup:ResourceGroupName','Update-AzSqlSyncMember:ResourceGroupName','Update-AzSqlSyncSchema:ResourceGroupName','Get-AzSqlDatabaseDataMaskingPolicy:ResourceGroupName','Get-AzSqlDatabaseDataMaskingRule:ResourceGroupName','New-AzSqlDatabaseDataMaskingRule:ResourceGroupName','Remove-AzSqlDatabaseDataMaskingRule:ResourceGroupName','Set-AzSqlDatabaseDataMaskingPolicy:ResourceGroupName','Set-AzSqlDatabaseDataMaskingRule:ResourceGroupName','Get-AzSqlDatabaseAdvisor:ResourceGroupName','Get-AzSqlElasticPoolAdvisor:ResourceGroupName','Get-AzSqlServerAdvisor:ResourceGroupName','Set-AzSqlDatabaseAdvisorAutoExecuteStatus:ResourceGroupName','Set-AzSqlElasticPoolAdvisorAutoExecuteStatus:ResourceGroupName','Set-AzSqlServerAdvisorAutoExecuteStatus:ResourceGroupName','Disable-AzSqlInstanceAdvancedDataSecurity:ResourceGroupName','Disable-AzSqlServerAdvancedDataSecurity:ResourceGroupName','Enable-AzSqlInstanceAdvancedDataSecurity:ResourceGroupName','Enable-AzSqlServerAdvancedDataSecurity:ResourceGroupName','Get-AzSqlInstanceAdvancedDataSecurityPolicy:ResourceGroupName','Get-AzSqlServerAdvancedDataSecurityPolicy:ResourceGroupName','Get-AzSqlDatabaseAdvancedThreatProtectionSetting:ResourceGroupName','Get-AzSqlInstanceDatabaseAdvancedThreatProtectionSetting:ResourceGroupName','Get-AzSqlInstanceAdvancedThreatProtectionSetting:ResourceGroupName','Get-AzSqlServerAdvancedThreatProtectionSetting:ResourceGroupName','Update-AzSqlDatabaseAdvancedThreatProtectionSetting:ResourceGroupName','Update-AzSqlInstanceDatabaseAdvancedThreatProtectionSetting:ResourceGroupName','Update-AzSqlInstanceAdvancedThreatProtectionSetting:ResourceGroupName','Update-AzSqlServerAdvancedThreatProtectionSetting:ResourceGroupName')

if ($Env:ACC_CLOUD -eq $null)
{
    $FilteredCommands | ForEach-Object {

        $existingDefault = $false
        foreach ($key in $global:PSDefaultParameterValues.Keys)
        {
            if ($_ -like "$key")
            {
                $existingDefault = $true
            }
        }

        if (!$existingDefault)
        {
            $global:PSDefaultParameterValues.Add($_,
                {
                    if ((Get-Command Get-AzContext -ErrorAction Ignore) -eq $null)
                    {
                        $context = Get-AzureRmContext
                    }
                    else
                    {
                        $context = Get-AzContext
                    }
                    if (($context -ne $null) -and $context.ExtendedProperties.ContainsKey("Default Resource Group")) {
                        $context.ExtendedProperties["Default Resource Group"]
                    }
                })
        }
    }
}



# SIG # Begin signature block
# MIIoLQYJKoZIhvcNAQcCoIIoHjCCKBoCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCCxWQbLBzaEKv0m
# ZTIz6kWQLIw9EVlBq4+YGRmikcQ49qCCDXYwggX0MIID3KADAgECAhMzAAADTrU8
# esGEb+srAAAAAANOMA0GCSqGSIb3DQEBCwUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjMwMzE2MTg0MzI5WhcNMjQwMzE0MTg0MzI5WjB0MQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMR4wHAYDVQQDExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB
# AQDdCKiNI6IBFWuvJUmf6WdOJqZmIwYs5G7AJD5UbcL6tsC+EBPDbr36pFGo1bsU
# p53nRyFYnncoMg8FK0d8jLlw0lgexDDr7gicf2zOBFWqfv/nSLwzJFNP5W03DF/1
# 1oZ12rSFqGlm+O46cRjTDFBpMRCZZGddZlRBjivby0eI1VgTD1TvAdfBYQe82fhm
# WQkYR/lWmAK+vW/1+bO7jHaxXTNCxLIBW07F8PBjUcwFxxyfbe2mHB4h1L4U0Ofa
# +HX/aREQ7SqYZz59sXM2ySOfvYyIjnqSO80NGBaz5DvzIG88J0+BNhOu2jl6Dfcq
# jYQs1H/PMSQIK6E7lXDXSpXzAgMBAAGjggFzMIIBbzAfBgNVHSUEGDAWBgorBgEE
# AYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQUnMc7Zn/ukKBsBiWkwdNfsN5pdwAw
# RQYDVR0RBD4wPKQ6MDgxHjAcBgNVBAsTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEW
# MBQGA1UEBRMNMjMwMDEyKzUwMDUxNjAfBgNVHSMEGDAWgBRIbmTlUAXTgqoXNzci
# tW2oynUClTBUBgNVHR8ETTBLMEmgR6BFhkNodHRwOi8vd3d3Lm1pY3Jvc29mdC5j
# b20vcGtpb3BzL2NybC9NaWNDb2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3JsMGEG
# CCsGAQUFBwEBBFUwUzBRBggrBgEFBQcwAoZFaHR0cDovL3d3dy5taWNyb3NvZnQu
# Y29tL3BraW9wcy9jZXJ0cy9NaWNDb2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3J0
# MAwGA1UdEwEB/wQCMAAwDQYJKoZIhvcNAQELBQADggIBAD21v9pHoLdBSNlFAjmk
# mx4XxOZAPsVxxXbDyQv1+kGDe9XpgBnT1lXnx7JDpFMKBwAyIwdInmvhK9pGBa31
# TyeL3p7R2s0L8SABPPRJHAEk4NHpBXxHjm4TKjezAbSqqbgsy10Y7KApy+9UrKa2
# kGmsuASsk95PVm5vem7OmTs42vm0BJUU+JPQLg8Y/sdj3TtSfLYYZAaJwTAIgi7d
# hzn5hatLo7Dhz+4T+MrFd+6LUa2U3zr97QwzDthx+RP9/RZnur4inzSQsG5DCVIM
# pA1l2NWEA3KAca0tI2l6hQNYsaKL1kefdfHCrPxEry8onJjyGGv9YKoLv6AOO7Oh
# JEmbQlz/xksYG2N/JSOJ+QqYpGTEuYFYVWain7He6jgb41JbpOGKDdE/b+V2q/gX
# UgFe2gdwTpCDsvh8SMRoq1/BNXcr7iTAU38Vgr83iVtPYmFhZOVM0ULp/kKTVoir
# IpP2KCxT4OekOctt8grYnhJ16QMjmMv5o53hjNFXOxigkQWYzUO+6w50g0FAeFa8
# 5ugCCB6lXEk21FFB1FdIHpjSQf+LP/W2OV/HfhC3uTPgKbRtXo83TZYEudooyZ/A
# Vu08sibZ3MkGOJORLERNwKm2G7oqdOv4Qj8Z0JrGgMzj46NFKAxkLSpE5oHQYP1H
# tPx1lPfD7iNSbJsP6LiUHXH1MIIHejCCBWKgAwIBAgIKYQ6Q0gAAAAAAAzANBgkq
# hkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
# EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
# bjEyMDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5
# IDIwMTEwHhcNMTEwNzA4MjA1OTA5WhcNMjYwNzA4MjEwOTA5WjB+MQswCQYDVQQG
# EwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
# A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQg
# Q29kZSBTaWduaW5nIFBDQSAyMDExMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIIC
# CgKCAgEAq/D6chAcLq3YbqqCEE00uvK2WCGfQhsqa+laUKq4BjgaBEm6f8MMHt03
# a8YS2AvwOMKZBrDIOdUBFDFC04kNeWSHfpRgJGyvnkmc6Whe0t+bU7IKLMOv2akr
# rnoJr9eWWcpgGgXpZnboMlImEi/nqwhQz7NEt13YxC4Ddato88tt8zpcoRb0Rrrg
# OGSsbmQ1eKagYw8t00CT+OPeBw3VXHmlSSnnDb6gE3e+lD3v++MrWhAfTVYoonpy
# 4BI6t0le2O3tQ5GD2Xuye4Yb2T6xjF3oiU+EGvKhL1nkkDstrjNYxbc+/jLTswM9
# sbKvkjh+0p2ALPVOVpEhNSXDOW5kf1O6nA+tGSOEy/S6A4aN91/w0FK/jJSHvMAh
# dCVfGCi2zCcoOCWYOUo2z3yxkq4cI6epZuxhH2rhKEmdX4jiJV3TIUs+UsS1Vz8k
# A/DRelsv1SPjcF0PUUZ3s/gA4bysAoJf28AVs70b1FVL5zmhD+kjSbwYuER8ReTB
# w3J64HLnJN+/RpnF78IcV9uDjexNSTCnq47f7Fufr/zdsGbiwZeBe+3W7UvnSSmn
# Eyimp31ngOaKYnhfsi+E11ecXL93KCjx7W3DKI8sj0A3T8HhhUSJxAlMxdSlQy90
# lfdu+HggWCwTXWCVmj5PM4TasIgX3p5O9JawvEagbJjS4NaIjAsCAwEAAaOCAe0w
# ggHpMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1UdDgQWBBRIbmTlUAXTgqoXNzcitW2o
# ynUClTAZBgkrBgEEAYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYD
# VR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBRyLToCMZBDuRQFTuHqp8cx0SOJNDBa
# BgNVHR8EUzBRME+gTaBLhklodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2Ny
# bC9wcm9kdWN0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFfMDNfMjIuY3JsMF4GCCsG
# AQUFBwEBBFIwUDBOBggrBgEFBQcwAoZCaHR0cDovL3d3dy5taWNyb3NvZnQuY29t
# L3BraS9jZXJ0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFfMDNfMjIuY3J0MIGfBgNV
# HSAEgZcwgZQwgZEGCSsGAQQBgjcuAzCBgzA/BggrBgEFBQcCARYzaHR0cDovL3d3
# dy5taWNyb3NvZnQuY29tL3BraW9wcy9kb2NzL3ByaW1hcnljcHMuaHRtMEAGCCsG
# AQUFBwICMDQeMiAdAEwAZQBnAGEAbABfAHAAbwBsAGkAYwB5AF8AcwB0AGEAdABl
# AG0AZQBuAHQALiAdMA0GCSqGSIb3DQEBCwUAA4ICAQBn8oalmOBUeRou09h0ZyKb
# C5YR4WOSmUKWfdJ5DJDBZV8uLD74w3LRbYP+vj/oCso7v0epo/Np22O/IjWll11l
# hJB9i0ZQVdgMknzSGksc8zxCi1LQsP1r4z4HLimb5j0bpdS1HXeUOeLpZMlEPXh6
# I/MTfaaQdION9MsmAkYqwooQu6SpBQyb7Wj6aC6VoCo/KmtYSWMfCWluWpiW5IP0
# wI/zRive/DvQvTXvbiWu5a8n7dDd8w6vmSiXmE0OPQvyCInWH8MyGOLwxS3OW560
# STkKxgrCxq2u5bLZ2xWIUUVYODJxJxp/sfQn+N4sOiBpmLJZiWhub6e3dMNABQam
# ASooPoI/E01mC8CzTfXhj38cbxV9Rad25UAqZaPDXVJihsMdYzaXht/a8/jyFqGa
# J+HNpZfQ7l1jQeNbB5yHPgZ3BtEGsXUfFL5hYbXw3MYbBL7fQccOKO7eZS/sl/ah
# XJbYANahRr1Z85elCUtIEJmAH9AAKcWxm6U/RXceNcbSoqKfenoi+kiVH6v7RyOA
# 9Z74v2u3S5fi63V4GuzqN5l5GEv/1rMjaHXmr/r8i+sLgOppO6/8MO0ETI7f33Vt
# Y5E90Z1WTk+/gFcioXgRMiF670EKsT/7qMykXcGhiJtXcVZOSEXAQsmbdlsKgEhr
# /Xmfwb1tbWrJUnMTDXpQzTGCGg0wghoJAgEBMIGVMH4xCzAJBgNVBAYTAlVTMRMw
# EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
# aWNyb3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNp
# Z25pbmcgUENBIDIwMTECEzMAAANOtTx6wYRv6ysAAAAAA04wDQYJYIZIAWUDBAIB
# BQCgga4wGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEO
# MAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEIL0QySbzyqT9NtqYVo1ni7HC
# RYalPouZKRdEXCT/EQVSMEIGCisGAQQBgjcCAQwxNDAyoBSAEgBNAGkAYwByAG8A
# cwBvAGYAdKEagBhodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20wDQYJKoZIhvcNAQEB
# BQAEggEAH/drDpaGuU2mwr3aaflEisLsLvzCz35cFx3BFRHZrR4xdnwmZkpZGa3u
# qD9QTa+w8X8X0g9YE4yx/OTmdHmVrZ0DNi2r+UCNDGTr+8FpO61kmNJ36u1zuypt
# UtIjfjaMQ0BjyEnX0pPE1oHRtat/zTnxWq55/Tuhv/MguKO9XR1EUpkfTGOwJqIf
# mifdDt1THQCWDz7PNsaAKjsHS1IXLB/GE0feBBG3q5FBl8/E6/KvmPDXB11+Cz6F
# TkPVkR9Kp7KQRxOxLu3cKiy/XGWggEj1Uaj+IKw7IRHIfzSKG85Z5/nGUH23j6Z9
# /MnkUHxJotpMMYN4DeFsKD2WUHqXtaGCF5cwgheTBgorBgEEAYI3AwMBMYIXgzCC
# F38GCSqGSIb3DQEHAqCCF3AwghdsAgEDMQ8wDQYJYIZIAWUDBAIBBQAwggFSBgsq
# hkiG9w0BCRABBKCCAUEEggE9MIIBOQIBAQYKKwYBBAGEWQoDATAxMA0GCWCGSAFl
# AwQCAQUABCA5PILb/zzqUOeNLPI/zi3/fVEQQ4+vlVJzlqhLahTciwIGZNTKw3Or
# GBMyMDIzMDgzMDA2MzMxNC41MzVaMASAAgH0oIHRpIHOMIHLMQswCQYDVQQGEwJV
# UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UE
# ChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1l
# cmljYSBPcGVyYXRpb25zMScwJQYDVQQLEx5uU2hpZWxkIFRTUyBFU046REMwMC0w
# NUUwLUQ5NDcxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZpY2Wg
# ghHtMIIHIDCCBQigAwIBAgITMwAAAdIhJDFKWL8tEQABAAAB0jANBgkqhkiG9w0B
# AQsFADB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UE
# BxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYD
# VQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDAeFw0yMzA1MjUxOTEy
# MjFaFw0yNDAyMDExOTEyMjFaMIHLMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2Fz
# aGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENv
# cnBvcmF0aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1lcmljYSBPcGVyYXRpb25z
# MScwJQYDVQQLEx5uU2hpZWxkIFRTUyBFU046REMwMC0wNUUwLUQ5NDcxJTAjBgNV
# BAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZpY2UwggIiMA0GCSqGSIb3DQEB
# AQUAA4ICDwAwggIKAoICAQDcYIhC0QI/SPaT5+nYSBsSdhBPO2SXM40Vyyg8Fq1T
# PrMNDzxChxWUD7fbKwYGSsONgtjjVed5HSh5il75jNacb6TrZwuX+Q2++f2/8CCy
# u8TY0rxEInD3Tj52bWz5QRWVQejfdCA/n6ZzinhcZZ7+VelWgTfYC7rDrhX3TBX8
# 9elqXmISOVIWeXiRK8h9hH6SXgjhQGGQbf2bSM7uGkKzJ/pZ2LvlTzq+mOW9iP2j
# cYEA4bpPeurpglLVUSnGGQLmjQp7Sdy1wE52WjPKdLnBF6JbmSREM/Dj9Z7okxRN
# UjYSdgyvZ1LWSilhV/wegYXVQ6P9MKjRnE8CI5KMHmq7EsHhIBK0B99dFQydL1vd
# uC7eWEjzz55Z/DyH6Hl2SPOf5KZ4lHf6MUwtgaf+MeZxkW0ixh/vL1mX8VsJTHa8
# AH+0l/9dnWzFMFFJFG7g95nHJ6MmYPrfmoeKORoyEQRsSus2qCrpMjg/P3Z9WJAt
# FGoXYMD19NrzG4UFPpVbl3N1XvG4/uldo1+anBpDYhxQU7k1gfHn6QxdUU0TsrJ/
# JCvLffS89b4VXlIaxnVF6QZh+J7xLUNGtEmj6dwPzoCfL7zqDZJvmsvYNk1lcbyV
# xMIgDFPoA2fZPXHF7dxahM2ZG7AAt3vZEiMtC6E/ciLRcIwzlJrBiHEenIPvxW15
# qwIDAQABo4IBSTCCAUUwHQYDVR0OBBYEFCC2n7cnR3ToP/kbEZ2XJFFmZ1kkMB8G
# A1UdIwQYMBaAFJ+nFV0AXmJdg/Tl0mWnG1M1GelyMF8GA1UdHwRYMFYwVKBSoFCG
# Tmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvY3JsL01pY3Jvc29mdCUy
# MFRpbWUtU3RhbXAlMjBQQ0ElMjAyMDEwKDEpLmNybDBsBggrBgEFBQcBAQRgMF4w
# XAYIKwYBBQUHMAKGUGh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvY2Vy
# dHMvTWljcm9zb2Z0JTIwVGltZS1TdGFtcCUyMFBDQSUyMDIwMTAoMSkuY3J0MAwG
# A1UdEwEB/wQCMAAwFgYDVR0lAQH/BAwwCgYIKwYBBQUHAwgwDgYDVR0PAQH/BAQD
# AgeAMA0GCSqGSIb3DQEBCwUAA4ICAQCw5iq0Ey0LlAdz2PcqchRwW5d+fitNISCv
# qD0E6W/AyiTk+TM3WhYTaxQ2pP6Or4qOV+Du7/L+k18gYr1phshxVMVnXNcdjecM
# tTWUOVAwbJoeWHaAgknNIMzXK3+zguG5TVcLEh/CVMy1J7KPE8Q0Cz56NgWzd9ur
# G+shSDKkKdhOYPXF970Mr1GCFFpe1oXjEy6aS+Heavp2wmy65mbu0AcUOPEn+hYq
# ijgLXSPqvuFmOOo5UnSV66Dv5FdkqK7q5DReox9RPEZcHUa+2BUKPjp+dQ3D4c9I
# H8727KjMD8OXZomD9A8Mr/fcDn5FI7lfZc8ghYc7spYKTO/0Z9YRRamhVWxxrIsB
# N5LrWh+18soXJ++EeSjzSYdgGWYPg16hL/7Aydx4Kz/WBTUmbGiiVUcE/I0aQU2U
# /0NzUiIFIW80SvxeDWn6I+hyVg/sdFSALP5JT7wAe8zTvsrI2hMpEVLdStFAMqan
# FYqtwZU5FoAsoPZ7h1ElWmKLZkXk8ePuALztNY1yseO0TwdueIGcIwItrlBYg1Xp
# Pz1+pMhGMVble6KHunaKo5K/ldOM0mQQT4Vjg6ZbzRIVRoDcArQ5//0875jOUvJt
# Yyc7Hl04jcmvjEIXC3HjkUYvgHEWL0QF/4f7vLAchaEZ839/3GYOdqH5VVnZrUIB
# QB6DTaUILDCCB3EwggVZoAMCAQICEzMAAAAVxedrngKbSZkAAAAAABUwDQYJKoZI
# hvcNAQELBQAwgYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAw
# DgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
# MjAwBgNVBAMTKU1pY3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0eSAy
# MDEwMB4XDTIxMDkzMDE4MjIyNVoXDTMwMDkzMDE4MzIyNVowfDELMAkGA1UEBhMC
# VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
# BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRp
# bWUtU3RhbXAgUENBIDIwMTAwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoIC
# AQDk4aZM57RyIQt5osvXJHm9DtWC0/3unAcH0qlsTnXIyjVX9gF/bErg4r25Phdg
# M/9cT8dm95VTcVrifkpa/rg2Z4VGIwy1jRPPdzLAEBjoYH1qUoNEt6aORmsHFPPF
# dvWGUNzBRMhxXFExN6AKOG6N7dcP2CZTfDlhAnrEqv1yaa8dq6z2Nr41JmTamDu6
# GnszrYBbfowQHJ1S/rboYiXcag/PXfT+jlPP1uyFVk3v3byNpOORj7I5LFGc6XBp
# Dco2LXCOMcg1KL3jtIckw+DJj361VI/c+gVVmG1oO5pGve2krnopN6zL64NF50Zu
# yjLVwIYwXE8s4mKyzbnijYjklqwBSru+cakXW2dg3viSkR4dPf0gz3N9QZpGdc3E
# XzTdEonW/aUgfX782Z5F37ZyL9t9X4C626p+Nuw2TPYrbqgSUei/BQOj0XOmTTd0
# lBw0gg/wEPK3Rxjtp+iZfD9M269ewvPV2HM9Q07BMzlMjgK8QmguEOqEUUbi0b1q
# GFphAXPKZ6Je1yh2AuIzGHLXpyDwwvoSCtdjbwzJNmSLW6CmgyFdXzB0kZSU2LlQ
# +QuJYfM2BjUYhEfb3BvR/bLUHMVr9lxSUV0S2yW6r1AFemzFER1y7435UsSFF5PA
# PBXbGjfHCBUYP3irRbb1Hode2o+eFnJpxq57t7c+auIurQIDAQABo4IB3TCCAdkw
# EgYJKwYBBAGCNxUBBAUCAwEAATAjBgkrBgEEAYI3FQIEFgQUKqdS/mTEmr6CkTxG
# NSnPEP8vBO4wHQYDVR0OBBYEFJ+nFV0AXmJdg/Tl0mWnG1M1GelyMFwGA1UdIARV
# MFMwUQYMKwYBBAGCN0yDfQEBMEEwPwYIKwYBBQUHAgEWM2h0dHA6Ly93d3cubWlj
# cm9zb2Z0LmNvbS9wa2lvcHMvRG9jcy9SZXBvc2l0b3J5Lmh0bTATBgNVHSUEDDAK
# BggrBgEFBQcDCDAZBgkrBgEEAYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMC
# AYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBTV9lbLj+iiXGJo0T2UkFvX
# zpoYxDBWBgNVHR8ETzBNMEugSaBHhkVodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20v
# cGtpL2NybC9wcm9kdWN0cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0yMy5jcmwwWgYI
# KwYBBQUHAQEETjBMMEoGCCsGAQUFBzAChj5odHRwOi8vd3d3Lm1pY3Jvc29mdC5j
# b20vcGtpL2NlcnRzL01pY1Jvb0NlckF1dF8yMDEwLTA2LTIzLmNydDANBgkqhkiG
# 9w0BAQsFAAOCAgEAnVV9/Cqt4SwfZwExJFvhnnJL/Klv6lwUtj5OR2R4sQaTlz0x
# M7U518JxNj/aZGx80HU5bbsPMeTCj/ts0aGUGCLu6WZnOlNN3Zi6th542DYunKmC
# VgADsAW+iehp4LoJ7nvfam++Kctu2D9IdQHZGN5tggz1bSNU5HhTdSRXud2f8449
# xvNo32X2pFaq95W2KFUn0CS9QKC/GbYSEhFdPSfgQJY4rPf5KYnDvBewVIVCs/wM
# nosZiefwC2qBwoEZQhlSdYo2wh3DYXMuLGt7bj8sCXgU6ZGyqVvfSaN0DLzskYDS
# PeZKPmY7T7uG+jIa2Zb0j/aRAfbOxnT99kxybxCrdTDFNLB62FD+CljdQDzHVG2d
# Y3RILLFORy3BFARxv2T5JL5zbcqOCb2zAVdJVGTZc9d/HltEAY5aGZFrDZ+kKNxn
# GSgkujhLmm77IVRrakURR6nxt67I6IleT53S0Ex2tVdUCbFpAUR+fKFhbHP+Crvs
# QWY9af3LwUFJfn6Tvsv4O+S3Fb+0zj6lMVGEvL8CwYKiexcdFYmNcP7ntdAoGokL
# jzbaukz5m/8K6TT4JDVnK+ANuOaMmdbhIurwJ0I9JZTmdHRbatGePu1+oDEzfbzL
# 6Xu/OHBE0ZDxyKs6ijoIYn/ZcGNTTY3ugm2lBRDBcQZqELQdVTNYs6FwZvKhggNQ
# MIICOAIBATCB+aGB0aSBzjCByzELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
# bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
# b3JhdGlvbjElMCMGA1UECxMcTWljcm9zb2Z0IEFtZXJpY2EgT3BlcmF0aW9uczEn
# MCUGA1UECxMeblNoaWVsZCBUU1MgRVNOOkRDMDAtMDVFMC1EOTQ3MSUwIwYDVQQD
# ExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNloiMKAQEwBwYFKw4DAhoDFQCJ
# ptLCZsE06NtmHQzB5F1TroFSBqCBgzCBgKR+MHwxCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1w
# IFBDQSAyMDEwMA0GCSqGSIb3DQEBCwUAAgUA6Jj8KTAiGA8yMDIzMDgyOTIzMjIx
# N1oYDzIwMjMwODMwMjMyMjE3WjB3MD0GCisGAQQBhFkKBAExLzAtMAoCBQDomPwp
# AgEAMAoCAQACAjR3AgH/MAcCAQACAhKXMAoCBQDomk2pAgEAMDYGCisGAQQBhFkK
# BAIxKDAmMAwGCisGAQQBhFkKAwKgCjAIAgEAAgMHoSChCjAIAgEAAgMBhqAwDQYJ
# KoZIhvcNAQELBQADggEBABEHLEWgFkMGA0gVMUHaiOdM4fJ3kCTJYYkZmlsnlhBa
# Pfai+IHGTIIwZbyNvl/4Z4wSe62qZsayykDBhb4D9PTzCfj7IlTF4P8Auy0fA6du
# O6el2NdqAKrBWBGeqMc5CXTovCjmk6A4XLsof1P2CHMVbaS84DlC/VN9J7b3JT1W
# dY1MU80ShIPLLCGnWhcboIC2dpTkfJ1caQcqYIJxWX8dFmaUw0YZV97LQPUCmeqL
# A3OOtEWIPB5oK9jdobuAw0IBALCo8lBhokNCDMCj2H5Ty9d6+EOKT0DWy67TZ5yb
# KLYLfR1JJx5D/UXdqsSvH8hj0ZGR7pQ4ibxH2b+tPUAxggQNMIIECQIBATCBkzB8
# MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
# bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1N
# aWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMAITMwAAAdIhJDFKWL8tEQABAAAB
# 0jANBglghkgBZQMEAgEFAKCCAUowGgYJKoZIhvcNAQkDMQ0GCyqGSIb3DQEJEAEE
# MC8GCSqGSIb3DQEJBDEiBCCiOi+mez50I+mKg+/v//eCn7EgoTv1hkLGRv1quyFk
# xjCB+gYLKoZIhvcNAQkQAi8xgeowgecwgeQwgb0EIMeAIJPf30i9ZbOExU557GwW
# NaLH0Z5s65JFga2DeaROMIGYMIGApH4wfDELMAkGA1UEBhMCVVMxEzARBgNVBAgT
# Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29m
# dCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENB
# IDIwMTACEzMAAAHSISQxSli/LREAAQAAAdIwIgQgleoaUNKaDSmrRvjZgGe8nSCr
# zdtugxH7Y2jHXg0Dm2owDQYJKoZIhvcNAQELBQAEggIAJ7ohsQDK3deZPJl9SUOl
# kLpeUfFIGd2ZkAU3LyJo5K2Di2VqiszmhiH+n2xaDto8dq2YxsoLXWdLIlZV03Wa
# FEaDdPzB8rDNQLLRZp/AAj008q+Z2FjhBRHLmghsD1BCzRdJNATcoSQFlN79IL8s
# 6zu4Fb64LdkY8wtBW8laDbrYaNWTVYI+kz/WY4NQaaxUdSSMhFCTIJCQVGV5Nm7f
# zdw3P6Dhs5jDySOz5PuW5X9KICFBPIXlaqLi/pNYaEzgak7RdrpvLhyQgSZn9thW
# HVVzlRt0C448JLWnfIUMCeyZtDbtA1idm1+PB7YY9+yOLvbkv9wa5hoTWJntfI+k
# FPtl+GAZ8Mf3gjRFqX+R11SztcH8I7f53eocyH/d5cojrz4kkYiV6Yxo+BH97bCm
# 3tScXvRWs+IXRMNG1Y97673M9FSLBU/oFc6rO7MBGcUFlFU57O+r82JelsiEuzJs
# 8rsEN4CdiWERtooYM24Xi8MOKr6l1GEEb19nHtiFrcWCVQn26alDsZ9nJ/KHpJRb
# D2v2trgLvEnX9Peh7cjbz2AkOK3fqUE2D76kIV8yyxHgvgd0XuXPqlTkILrZ8+pr
# KvvUWBFHSUQONcJR0AWbFhrp7o7eYCj2PHOFe/FGqdfdkaNkHs0PyoQzE9uy9z27
# +MuAF9yjcxpLldfE1LOnyXA=
# SIG # End signature block
